@@ -2,7 +2,7 @@
 # more than one place in XMLTV.  But not general enough to merge back
 # into Memoize.
 #
-# $Id: Memoize.pm,v 1.15 2006/01/11 18:01:38 mattiasholmlund Exp $
+# $Id: Memoize.pm,v 1.17 2014/06/22 10:34:33 stefanb2 Exp $
 #
 
 package XMLTV::Memoize;
@@ -74,8 +74,9 @@ sub check_argv( @ ) {
     require POSIX;
     require Memoize;
     require DB_File;
-    my @tie_args = ('DB_File', $filename,
-		    POSIX::O_RDWR() | POSIX::O_CREAT(), 0666);
+    # Annoyingly tie(%cache, @tie_args) doesn't work
+    #my @tie_args = ('DB_File', $filename,
+    #		    POSIX::O_RDWR() | POSIX::O_CREAT(), 0666);
 
     # $from_caller is a sub which converts a function name into one
     # seen from the caller's namespace.  Namespaces do not nest, so if
@@ -98,7 +99,19 @@ sub check_argv( @ ) {
     foreach (@_) {
 	my $r = Memoize::memoize($from_caller->($_),
 				 SCALAR_CACHE => [ HASH => \%cache ],
-				 LIST_CACHE => 'MERGE');
+				 #
+				 # Memoize 1.03 broke tied SCALAR_CACHE with
+				 # together with LIST_CACHE => 'MERGE'. See
+				 # bug report on CPAN:
+				 #
+				 #  https://rt.cpan.org/Public/Bug/Display.html?id=91927
+				 #
+				 # As no user of this module calls memoized
+				 # functions in list context, we can simply
+				 # replace it with 'FAULT'.
+				 #
+				 #LIST_CACHE => 'MERGE');
+				 LIST_CACHE => 'FAULT');
 	die "could not memoize $_" if not $r;
 	push @r, $r;
     }
