@@ -6,7 +6,7 @@
 #
 # Setup
 #
-# VERSION: $Id: foxtv.pm,v 2.04 2016/05/15 16:58:19 stefanb2 Exp $
+# VERSION: $Id: foxtv.pm,v 2.05 2017/07/12 19:33:02 stefanb2 Exp $
 #
 # INSERT FROM HERE ############################################################
 package fi::source::foxtv;
@@ -77,7 +77,7 @@ sub grab {
 
 	  if ($start && $title) {
 	    if (my($hour, $minute) =
-		$start->as_text() =~ /^(\d{2}):(\d{2})$/) {
+		$start->as_text() =~ /^(\d{2})[:.](\d{2})$/) {
 	      my $desc  = $programme->find("p");
 	      my $extra = $programme->find("h4");
 
